@@ -312,6 +312,30 @@ private slots:
                                                 + model.property("text").toString()));
     }
 
+    void shouldNotReactToTitleTrim()
+    {
+        // GIVEN
+        Widgets::EditorView editor;
+        EditorModelStub model;
+        model.makeTaskAvailable();
+        model.setProperty("title", "My title  ");
+        model.setProperty("text", "\nMy text");
+        model.setProperty("startDate", QDateTime::currentDateTime());
+        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("done", true);
+        editor.setModel(&model);
+
+        auto textEdit = editor.findChild<QPlainTextEdit*>("textEdit");
+
+        // WHEN
+        model.setPropertyAndSignal("title", "My title");
+
+        // THEN
+        QCOMPARE(textEdit->toPlainText(), QString(model.property("title").toString() + "  "
+                                                + "\n"
+                                                + model.property("text").toString()));
+    }
+
     void shouldReactToTextChanges()
     {
         // GIVEN
@@ -336,6 +360,40 @@ private slots:
                                                 + model.property("text").toString()));
     }
 
+    void shouldNotReactToTextTrim()
+    {
+        // GIVEN
+        Widgets::EditorView editor;
+        EditorModelStub model;
+        model.makeTaskAvailable();
+        model.setProperty("title", "My title");
+        model.setProperty("text", "\nMy text \n ");
+        model.setProperty("startDate", QDateTime::currentDateTime());
+        model.setProperty("dueDate", QDateTime::currentDateTime().addDays(2));
+        model.setProperty("done", true);
+        editor.setModel(&model);
+
+        auto textEdit = editor.findChild<QPlainTextEdit*>("textEdit");
+
+        // WHEN
+        model.setPropertyAndSignal("text", "\nMy text");
+
+        // THEN
+        QCOMPARE(textEdit->toPlainText(), QString(model.property("title").toString()
+                                                + "\n"
+                                                + model.property("text").toString() + " \n "));
+    }
+
+    void shouldApplyTextEditChanges_data()
+    {
+        QTest::addColumn<QString>("plainText");
+        QTest::addColumn<QString>("expectedTitle");
+        QTest::addColumn<QString>("expectedText");
+
+        QTest::newRow("nominal case") << "Title\n\nText" << "Title" << "\nText";
+        QTest::newRow("single line") << "Title" << "Title" << "";
+    }
+
     void shouldApplyTextEditChanges()
     {
         // GIVEN
@@ -347,11 +405,14 @@ private slots:
         auto textEdit = editor.findChild<QPlainTextEdit*>("textEdit");
 
         // WHEN
-        textEdit->setPlainText("Title\n\nText");
+        QFETCH(QString, plainText);
+        textEdit->setPlainText(plainText);
 
         // THEN
-        QCOMPARE(model.property("title").toString(), QString("Title"));
-        QCOMPARE(model.property("text").toString(), QString("\nText"));
+        QFETCH(QString, expectedTitle);
+        QCOMPARE(model.property("title").toString(), expectedTitle);
+        QFETCH(QString, expectedText);
+        QCOMPARE(model.property("text").toString(), expectedText);
     }
 
     void shouldReactToDoneChanges()
@@ -517,6 +578,24 @@ private slots:
         QCOMPARE(delegateLabel->text(), expectedText);
     }
 
+    void shouldClearDelegateEditOnArtifactChanges()
+    {
+        // GIVEN
+        Widgets::EditorView editor;
+        EditorModelStub model;
+        model.makeTaskAvailable();
+        editor.setModel(&model);
+
+        auto delegateEdit = editor.findChild<KLineEdit*>("delegateEdit");
+        delegateEdit->setText("Foo");
+
+        // WHEN
+        model.makeTaskAvailable(); // simulates an artifact change
+
+        // THEN
+        QVERIFY(delegateEdit->text().isEmpty());
+    }
+
     void shouldRequestDelegationOnInput_data()
     {
         QTest::addColumn<QString>("userInput");
